==> jc-1.4.0.tar.gz: java/awt/dnd/InvalidDnDOperationException.h <==
// public class java.awt.dnd.InvalidDnDOperationException

// class file dependencies
// @dep_class 53e083d824f7dacb java_awt_dnd_InvalidDnDOperationException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b7e704701c278e65 java_lang_IllegalStateException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_IllegalStateException

#include "java/lang/IllegalStateException.h"

#ifndef _JC_java_awt_dnd_InvalidDnDOperationException_H_
#define _JC_java_awt_dnd_InvalidDnDOperationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_dnd_InvalidDnDOperationException$sub_refs	_jc_java_awt_dnd_InvalidDnDOperationException$sub_refs;
typedef struct _jc_java_awt_dnd_InvalidDnDOperationException$sub_nonrefs	_jc_java_awt_dnd_InvalidDnDOperationException$sub_nonrefs;
typedef struct _jc_java_awt_dnd_InvalidDnDOperationException$refs	_jc_java_awt_dnd_InvalidDnDOperationException$refs;
typedef struct _jc_java_awt_dnd_InvalidDnDOperationException$nonrefs	_jc_java_awt_dnd_InvalidDnDOperationException$nonrefs;
typedef struct _jc_java_awt_dnd_InvalidDnDOperationException$object	_jc_java_awt_dnd_InvalidDnDOperationException$object;

typedef struct _jc_java_awt_dnd_InvalidDnDOperationException$fields_struct	_jc_java_awt_dnd_InvalidDnDOperationException$fields_struct;
typedef const struct _jc_java_awt_dnd_InvalidDnDOperationException$vmethods	_jc_java_awt_dnd_InvalidDnDOperationException$vmethods;
typedef const struct _jc_java_awt_dnd_InvalidDnDOperationException$vtable	_jc_java_awt_dnd_InvalidDnDOperationException$vtable;
typedef const struct _jc_java_awt_dnd_InvalidDnDOperationException$vtype	_jc_java_awt_dnd_InvalidDnDOperationException$vtype;

// Class fields structure
struct _jc_java_awt_dnd_InvalidDnDOperationException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_dnd_InvalidDnDOperationException$fields_struct _jc_java_awt_dnd_InvalidDnDOperationException$class_fields;

// Constructors
extern void _jc_java_awt_dnd_InvalidDnDOperationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_dnd_InvalidDnDOperationException$object *);
extern void _jc_java_awt_dnd_InvalidDnDOperationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_dnd_InvalidDnDOperationException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_awt_dnd_InvalidDnDOperationException$vmethods {
};

// Vtable
struct _jc_java_awt_dnd_InvalidDnDOperationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalStateException$vmethods	java_lang_IllegalStateException;
	_jc_java_awt_dnd_InvalidDnDOperationException$vmethods	java_awt_dnd_InvalidDnDOperationException;
};

// Vtype
struct _jc_java_awt_dnd_InvalidDnDOperationException$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_InvalidDnDOperationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_InvalidDnDOperationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_InvalidDnDOperationException$refs {
    _jc_java_awt_dnd_InvalidDnDOperationException$sub_refs	java_awt_dnd_InvalidDnDOperationException;
    _jc_java_lang_IllegalStateException$sub_refs	java_lang_IllegalStateException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_InvalidDnDOperationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_InvalidDnDOperationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalStateException$sub_nonrefs	java_lang_IllegalStateException;
    _jc_java_awt_dnd_InvalidDnDOperationException$sub_nonrefs	java_awt_dnd_InvalidDnDOperationException;
};

// Object instance structure
struct _jc_java_awt_dnd_InvalidDnDOperationException$object {
	_jc_java_awt_dnd_InvalidDnDOperationException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_InvalidDnDOperationException$vtype	*vtype;
	_jc_java_awt_dnd_InvalidDnDOperationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_InvalidDnDOperationException$vtype _jc_java_awt_dnd_InvalidDnDOperationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_InvalidDnDOperationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_InvalidDnDOperationException$class_object;

#endif	/* _JC_java_awt_dnd_InvalidDnDOperationException_H_ */

==> jc-1.4.6.tar.gz: java/awt/dnd/InvalidDnDOperationException.h <==
// public class java.awt.dnd.InvalidDnDOperationException

// class file dependencies
// @dep_class 53e083d824f7dacb java_awt_dnd_InvalidDnDOperationException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b7e704701c278e65 java_lang_IllegalStateException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_IllegalStateException

#include "java/lang/IllegalStateException.h"

#ifndef _JC_java_awt_dnd_InvalidDnDOperationException_H_
#define _JC_java_awt_dnd_InvalidDnDOperationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_dnd_InvalidDnDOperationException$sub_refs	_jc_java_awt_dnd_InvalidDnDOperationException$sub_refs;
typedef struct _jc_java_awt_dnd_InvalidDnDOperationException$sub_nonrefs	_jc_java_awt_dnd_InvalidDnDOperationException$sub_nonrefs;
typedef struct _jc_java_awt_dnd_InvalidDnDOperationException$refs	_jc_java_awt_dnd_InvalidDnDOperationException$refs;
typedef struct _jc_java_awt_dnd_InvalidDnDOperationException$nonrefs	_jc_java_awt_dnd_InvalidDnDOperationException$nonrefs;
typedef struct _jc_java_awt_dnd_InvalidDnDOperationException$object	_jc_java_awt_dnd_InvalidDnDOperationException$object;

typedef struct _jc_java_awt_dnd_InvalidDnDOperationException$fields_struct	_jc_java_awt_dnd_InvalidDnDOperationException$fields_struct;
typedef const struct _jc_java_awt_dnd_InvalidDnDOperationException$vmethods	_jc_java_awt_dnd_InvalidDnDOperationException$vmethods;
typedef const struct _jc_java_awt_dnd_InvalidDnDOperationException$vtable	_jc_java_awt_dnd_InvalidDnDOperationException$vtable;
typedef const struct _jc_java_awt_dnd_InvalidDnDOperationException$vtype	_jc_java_awt_dnd_InvalidDnDOperationException$vtype;

// Class fields structure
struct _jc_java_awt_dnd_InvalidDnDOperationException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_dnd_InvalidDnDOperationException$fields_struct _jc_java_awt_dnd_InvalidDnDOperationException$class_fields;

// Constructors
extern void _jc_java_awt_dnd_InvalidDnDOperationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_dnd_InvalidDnDOperationException$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_dnd_InvalidDnDOperationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_dnd_InvalidDnDOperationException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_dnd_InvalidDnDOperationException$vmethods {
};

// Vtable
struct _jc_java_awt_dnd_InvalidDnDOperationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalStateException$vmethods	java_lang_IllegalStateException;
	_jc_java_awt_dnd_InvalidDnDOperationException$vmethods	java_awt_dnd_InvalidDnDOperationException;
};

// Vtype
struct _jc_java_awt_dnd_InvalidDnDOperationException$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_InvalidDnDOperationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_InvalidDnDOperationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_InvalidDnDOperationException$refs {
    _jc_java_awt_dnd_InvalidDnDOperationException$sub_refs	java_awt_dnd_InvalidDnDOperationException;
    _jc_java_lang_IllegalStateException$sub_refs	java_lang_IllegalStateException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_InvalidDnDOperationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_InvalidDnDOperationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalStateException$sub_nonrefs	java_lang_IllegalStateException;
    _jc_java_awt_dnd_InvalidDnDOperationException$sub_nonrefs	java_awt_dnd_InvalidDnDOperationException;
};

// Object instance structure
struct _jc_java_awt_dnd_InvalidDnDOperationException$object {
	_jc_java_awt_dnd_InvalidDnDOperationException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_InvalidDnDOperationException$vtype	*vtype;
	_jc_java_awt_dnd_InvalidDnDOperationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_InvalidDnDOperationException$vtype _jc_java_awt_dnd_InvalidDnDOperationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_InvalidDnDOperationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_InvalidDnDOperationException$class_object;

#endif	/* _JC_java_awt_dnd_InvalidDnDOperationException_H_ */
